# $Id: ja.rb,v 1.3 2004/02/15 02:48:35 hitoshi Exp $
# Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
# You can redistribute it and/or modify it under the terms of
# the Ruby's licence.
module Hiki
  module Messages
    def msg_recent; ' ' end
    def msg_create; '' end
    def msg_diff; 'ʬ' end
    def msg_edit; 'Խ' end
    def msg_search; '' end
    def msg_admin; '' end
    def msg_search_result; '' end
    def msg_search_hits; '\'%s\'ޤڡ%dڡ桢%dڡĤޤ' end
    def msg_search_not_found; '\'%s\'ޤڡϸĤޤǤ' end
    def msg_search_comment; 'ƤΥڡñ򸡺ޤʸȾʸ϶̤ޤȾѥڡñڤȻꤷñƴޤڡ򸡺ޤ' end
    def msg_frontpage; 'ȥå' end
    def msg_hitory; '' end
    def msg_index; 'ڡ' end
    def msg_recent_changes; '' end
    def msg_newpage; '' end
    def msg_no_recent; '<P>¸ߤޤ</P>' end
    def msg_thanks; '꤬Ȥޤ' end
    def msg_save_conflict; 'ͤޤƤƥȥǥʤɤ¸ǿΥڡ򻲾ȸ˺ԽƤ' end
    def msg_time_format; "%Y-%m-%d #DAY# %H:%M:%S" end
    def msg_date_format; "%Y-%m-%d " end
    def msg_day; %w(      ) end
    def msg_preview; 'ʲΥץӥ塼ǧ꤬ʤХڡβˤ¸ܥ¸Ƥ' end
    def msg_mail_on; '᡼' end
    def msg_mail_off; '' end
    def msg_use; 'Ѥ' end
    def msg_unuse; 'Ѥʤ' end
    def msg_password_title; 'ѥѥ' end
    def msg_password_enter; 'ѥѥɤϤƤ' end
    def msg_password; 'ѥ' end
    def msg_ok; 'OK' end
    def msg_invalid_password; 'ѥɤְäƤޤޤ¸Ƥޤ' end
    def msg_save_config; '¸ޤ' end
    def msg_freeze; 'Υڡ뤵Ƥޤ¸ˤϴѤΥѥɤɬפǤ' end
    def msg_freeze_mark; '' end
    def msg_already_exist; 'ΥڡϤǤ¸ߤƤޤ' end
    def msg_page_not_exist; 'Υڡ¸ߤޤ󡣤ҡƤ:-)' end
    def msg_invalid_filename(s); "ʸޤޤƤ뤫Ĺ(#{s}Х)ĶƤޤڡ̾Ƥ" end
    def msg_delete; 'ڡޤ' end
    def msg_delete_page; 'ʲΥڡޤ' end
    def msg_follow_link; 'ʲΥ󥯤򤿤ɤäƤ: ' end
    def msg_match_title; '[ȥ˰]' end
    def msg_match_keyword; '[ɤ˰]' end
    def msg_duplicate_page_title; 'ꤷȥϴ¸ߤƤޤ' end
  end
end
